"use strict";

var assert = require('assert')
var namer = require('..')

suite('namer', function () {

  test('is a function', function() {
    assert.equal('function', typeof(namer))
  })

  test('returns an object containing named sorted arrays', function() {
    var names = namer('#ffa500')
    assert(!Array.isArray(names))
    assert(names.basic)
    assert(names.html)
    assert(names.ntc)
    assert(names.pantone)
    assert(names.roygbiv)
    assert(names.x11)
    assert.equal(names.basic[0].distance, 0)
  })

  test('matches inexact colors', function() {
    var names = namer('FF0001')
    assert.equal(names.basic[0].hex, '#FF0000')
    assert.equal(names.basic[0].name, 'red')
    assert.equal(Math.floor(names.basic[0].distance*100), 25)
  })


  test('matches exact colors', function() {
    var names = namer('0000FF')
    assert.equal(names.basic[0].hex, '#0000FF')
    assert.equal(names.basic[0].name, 'blue')
    assert.equal(names.basic[0].distance, 0)
  })

  test('accepts hex strings that include a hash symbol', function() {
    var names = namer('#0000FF')
    assert.equal(names.basic[0].hex, '#0000FF')
    assert.equal(names.basic[0].name, 'blue')
    assert.equal(names.basic[0].distance, 0)
  })

  test('accepts HSL input', function() {
    var names = namer("hsl(50,100%,50%)")
    assert.equal(names.basic[0].name, 'gold')
  })


  suite('lists', function() {

    test('are available as a property of the exported module', function() {
      assert(namer.lists)
    })

    test('are arrays of objects with keys `name` and `hex`', function() {
      for (var list in namer.lists) {
        namer.lists[list].forEach(function(color){
          assert(color.name);
          assert(color.hex);
        })
      }
    })

  })

})
